summaryrefslogtreecommitdiffstats
path: root/config-db
diff options
context:
space:
mode:
Diffstat (limited to 'config-db')
-rw-r--r--config-db/OpenSLX/ConfigDB.pm7
1 files changed, 4 insertions, 3 deletions
diff --git a/config-db/OpenSLX/ConfigDB.pm b/config-db/OpenSLX/ConfigDB.pm
index 5c49646e..8382f066 100644
--- a/config-db/OpenSLX/ConfigDB.pm
+++ b/config-db/OpenSLX/ConfigDB.pm
@@ -2434,11 +2434,11 @@ sub mergeDefaultAttributesIntoSystem
my $defaultSystem = $self->fetchSystemByFilter({name => '<<<default>>>'});
mergeAttributes($system, $defaultSystem, $originInfo, 'default-system');
# then merge any attributes found in the plugins that are installed
# into the vendor-OS:
if (ref $installedPlugins eq 'ARRAY' && @$installedPlugins) {
for my $plugin (@$installedPlugins) {
- mergeAttributes($system, $plugin, $originInfo, 'vendor-OS');
+ pushAttributes($system, $plugin, $originInfo, 'vendor-OS');
}
# the above will have merged stage1 attributes, too, so we remove
@@ -2450,6 +2450,7 @@ sub mergeDefaultAttributesIntoSystem
}
}
+ # finally push the attributes specified for the system itself
my $defaultClient = $self->fetchClientByFilter({name => '<<<default>>>'});
pushAttributes($system, $defaultClient, $originInfo, 'default-client');
@@ -2434,11 +2434,11 @@ sub mergeDefaultAttributesIntoSystem
my $defaultSystem = $self->fetchSystemByFilter({name => '<<<default>>>'});
mergeAttributes($system, $defaultSystem, $originInfo, 'default-system');
- # then merge any attributes found in the plugins that are installed
- # into the vendor-OS:
+ # push any attributes found in the plugins that are installed into
+ # the vendor-OS:
if (ref $installedPlugins eq 'ARRAY' && @$installedPlugins) {
for my $plugin (@$installedPlugins) {